==> nextcloud-app-bookmarks-1%3A10.3.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/nb.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bokmerker",
    "You deleted \"%s\"" : "Du slettet \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s slettet \"%2$s\"",
    "Someone deleted \"%s\"" : "Noen slettet \"%s\"",
    "You created folder \"%s\"" : "Du opprettet mappen \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s opprettet mappen \"%2$s\"",
    "Someone created folder \"%s\"" : "Noen opprettet mappen \"%s\"",
    "You moved folder \"%s\"" : "Du flyttet mappen \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s flyttet mappen \"%2$s\"",
    "Someone moved folder \"%s\"" : "Noen flyttet mappen \"%s\"",
    "You deleted folder \"%s\"" : "Du slettet mappen \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s slettet mappen \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Noen slettet mappen \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Du delte mappen \"%1$s\" med %2$s",
    "You shared folder \"%s\" with someone" : "Du delte mappen \"%s\" med noen",
    "%1$s shared folder \"%2$s\" with you" : "%1$s delte mappen \"%2$s\" med deg",
    "Someone shared folder \"%s\" with you" : "Noen delte mappen \"%s\" med deg",
    "No file provided for import" : "Ingen fil valgt for import",
    "Unsupported file type for import" : "Usupportert filtype for import",
    "Details" : "Detaljer",
    "Rename" : "Gi nytt navn",
    "Move" : "Flytt",
    "Delete" : "Slett",
    "Select all" : "Velg alle",
    "Select one or more tags" : "Velg en eller flere merkelapper",
    "New" : "Ny",
    "New folder" : "Ny mappe",
    "Enter a link" : "Skriv inn et lenke",
    "Add a bookmark" : "Legg til bokmerke",
    "Enter folder title" : "Skriv inn tittel",
    "Submit" : "Send inn",
    "Cancel" : "Avbryt",
    "Recent" : "Nylig",
    "Import" : "Importer",
    "Export" : "Eksporter",
    "Bookmarklet" : "Bookmarklet",
    "Title" : "Tittel",
    "Link" : "Lenke",
    "Tags" : "Merkelapper",
    "Notes" : "Notater",
    "Owner" : "Eier",
    "Sharing" : "Deling",
    "Share link" : "Share link",
    "Copy link" : "Kopier lenke",
    "Allow editing" : "Tillat redigering",
    "Link copied" : "Lenke kopiert",
    "Privacy" : "Personvern",
    "Performance" : "Ytelse",
    "Failed to save settings" : "Klarte ikke å lagre innstillinger",
    "Failed to load settings" : "Klarte ikke å laste inn innstillinger",
    "This URL is already bookmarked! Overwrite?" : "Denne lenken eksisterer allerede, ønsker du overskrive?",
    "Enter bookmark title" : "Skriv inn tittel",
    "Folder" : "Mappe",
    "Save" : "Lagre",
    "Failed to create bookmark" : "Klarte ikke å opprette bokmerke",
    "Bookmarks feed" : "Bokmerker-strøm"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-bookmarks-1%3A10.4.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/nb.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bokmerker",
    "You deleted \"%s\"" : "Du slettet \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s slettet \"%2$s\"",
    "Someone deleted \"%s\"" : "Noen slettet \"%s\"",
    "You created folder \"%s\"" : "Du opprettet mappen \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s opprettet mappen \"%2$s\"",
    "Someone created folder \"%s\"" : "Noen opprettet mappen \"%s\"",
    "You moved folder \"%s\"" : "Du flyttet mappen \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s flyttet mappen \"%2$s\"",
    "Someone moved folder \"%s\"" : "Noen flyttet mappen \"%s\"",
    "You deleted folder \"%s\"" : "Du slettet mappen \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s slettet mappen \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Noen slettet mappen \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Du delte mappen \"%1$s\" med %2$s",
    "You shared folder \"%s\" with someone" : "Du delte mappen \"%s\" med noen",
    "%1$s shared folder \"%2$s\" with you" : "%1$s delte mappen \"%2$s\" med deg",
    "Someone shared folder \"%s\" with you" : "Noen delte mappen \"%s\" med deg",
    "No file provided for import" : "Ingen fil valgt for import",
    "Unsupported file type for import" : "Usupportert filtype for import",
    "Details" : "Detaljer",
    "Rename" : "Gi nytt navn",
    "Move" : "Flytt",
    "Delete" : "Slett",
    "Select all" : "Velg alle",
    "Go back" : "Gå tilbake",
    "Select one or more tags" : "Velg en eller flere merkelapper",
    "New" : "Ny",
    "New folder" : "Ny mappe",
    "Enter a link" : "Skriv inn et lenke",
    "Add a bookmark" : "Legg til bokmerke",
    "Enter folder title" : "Skriv inn tittel",
    "Rename folder" : "Gi mappen nytt navn",
    "Delete folder" : "Slett mappe",
    "Choose folder" : "Velg mappe",
    "Submit" : "Send inn",
    "Cancel" : "Avbryt",
    "Recent" : "Nylig",
    "Shared with you" : "Delt med deg",
    "Files" : "Filer",
    "Import" : "Importer",
    "Export" : "Eksporter",
    "Bookmarklet" : "Bookmarklet",
    "Title" : "Tittel",
    "Link" : "Lenke",
    "Root folder" : "Hovedmappe",
    "Tags" : "Merkelapper",
    "Notes" : "Notater",
    "Open file" : "Åpne fil",
    "Projects" : "Prosjekter",
    "Owner" : "Eier",
    "Sharing" : "Deling",
    "Share link" : "Share link",
    "Copy link" : "Kopier lenke",
    "Allow editing" : "Tillat redigering",
    "Allow resharing" : "TIllat videre deling",
    "Link copied" : "Lenke kopiert",
    "Privacy" : "Personvern",
    "Performance" : "Ytelse",
    "Failed to save settings" : "Klarte ikke å lagre innstillinger",
    "Failed to load settings" : "Klarte ikke å laste inn innstillinger",
    "This URL is already bookmarked! Overwrite?" : "Denne lenken eksisterer allerede, ønsker du overskrive?",
    "Enter bookmark title" : "Skriv inn tittel",
    "Folder" : "Mappe",
    "Save" : "Lagre",
    "Failed to create bookmark" : "Klarte ikke å opprette bokmerke",
    "Bookmarks feed" : "Bokmerker-strøm"
},
"nplurals=2; plural=(n != 1);");
